#!/bin/bash
# Quick test to start the visualizer
# After starting, open http://localhost:8501 and click on a directory node

echo "Starting visualizer..."
echo "Once loaded, try clicking on directory nodes to expand them."
echo "Check the browser console for debug output."
echo ""
echo "Press Ctrl+C to stop"
echo ""

# Start the visualizer
mcp-vector-search visualize
